@@ -28,7 +28,7 @@
 #include "calprintdefaultplugins.h"
 #include "kcalprefs.h"
 #include "utils.h"
-#include "helper_p.h"
+
 
 #include <Item>
 
@@ -141,7 +141,7 @@ public:
     QString mDurationCaption, mDurationString;
 
 protected:
-    bool visit(const KCalCore::Event::Ptr &event) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Event::Ptr &event) override {
         if (event->dtStart().isValid())
         {
             mStartCaption =  i18n("Start date: ");
@@ -173,7 +173,7 @@ protected:
         }
         return true;
     }
-    bool visit(const KCalCore::Todo::Ptr &todo) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Todo::Ptr &todo) override {
         if (todo->hasStartDate())
         {
             mStartCaption =  i18n("Start date: ");
@@ -195,7 +195,7 @@ protected:
         }
         return true;
     }
-    bool visit(const KCalCore::Journal::Ptr &journal) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::Journal::Ptr &journal) override {
         mStartCaption = i18n("Start date: ");
         mStartString = KCalUtils::IncidenceFormatter::dateTimeToString(
             journal->dtStart(), journal->allDay(), false);
@@ -203,7 +203,7 @@ protected:
         mEndString.clear();
         return true;
     }
-    bool visit(const KCalCore::FreeBusy::Ptr &fb) Q_DECL_OVERRIDE {
+    bool visit(const KCalCore::FreeBusy::Ptr &fb) override {
         Q_UNUSED(fb);
         return true;
     }
